@@ -6,27 +6,35 @@ import click
 from neoload_cli_lib import tools, rest_crud, user_data, displayer, cli_exception
 from neoload_cli_lib.name_resolver import Resolver
 
-__endpoint = "v2/test-results"
+__endpoint = "/test-results"
 __operation_statistics = "/statistics"
 __operation_sla_global = "/slas/statistics"
 __operation_sla_test = "/slas/per-test"
 __operation_sla_interval = "/slas/per-interval"
 
-__resolver = Resolver(__endpoint)
+__resolver = Resolver(__endpoint, rest_crud.base_endpoint_with_workspace)
 
 meta_key = 'result id'
 
+def load_from_file(file):
+    try:
+        return json.load(file)
+    except json.JSONDecodeError as err:
+        raise cli_exception.CliException('%s\nThis command requires a valid Json input.\n'
+                                         'Example: neoload test-settings create {"name":"TestName"}' % str(err))
 
 @click.command()
 @click.argument('command',
-                type=click.Choice(['ls', 'summary', 'junitsla', 'put', 'delete', 'use'], case_sensitive=False),
+                type=click.Choice(['ls', 'summary', 'junitsla', 'put', 'patch', 'delete', 'use'], case_sensitive=False),
                 required=False)
 @click.argument("name", type=str, required=False)
 @click.option('--rename', help="")
 @click.option('--description', help="")
 @click.option('--quality-status', 'quality_status', type=click.Choice(['PASSED', 'FAILED']), help="")
 @click.option('--junit-file', 'junit_file', default="junit-sla.xml", help="Output the junit sla report to this path")
-def cli(command, name, rename, description, quality_status, junit_file):
+@click.option('--file', type=click.File('r'), help="Json file with the data to be sent to the API.")
+@click.option('--filter', help="Filter test results by fields. Mostly used filters are : name, scenario, project, status.")
+def cli(command, name, rename, description, quality_status, junit_file, file, filter):
     """
     ls       # Lists test results                                            .
     summary  # Display a summary of the result : SLAs and statistics         .
@@ -36,6 +44,7 @@ def cli(command, name, rename, description, quality_status, junit_file):
     use      # Remember the test result you want to work on. Example : neoload
     |          test-results use MyTest#1 ; neoload test-results summary      .
     """
+    rest_crud.set_current_command()
     if not command:
         print("command is mandatory. Please see neoload tests-results --help")
         return
@@ -45,7 +54,7 @@ def cli(command, name, rename, description, quality_status, junit_file):
     is_id = tools.is_id(name)
     # avoid to make two requests if we have not id.
     if command == "ls":
-        tools.ls(name, is_id, __resolver)
+        tools.ls(name, is_id, __resolver, filter, ['project','status','author','sort'])
         return
 
     __id = tools.get_id(name, __resolver, is_id)
@@ -62,12 +71,15 @@ def cli(command, name, rename, description, quality_status, junit_file):
         system_exit = summary(__id)
     elif command == "junitsla":
         junit(__id, junit_file)
-    elif command == "put":
-        put(__id, description, quality_status, rename)
     elif command == "delete":
         delete(__id)
         user_data.set_meta(meta_key, None)
-
+    else:
+        json_data = load_from_file(file) if file else create_json(rename, description, quality_status)
+        if command == "put":
+            put(__id, json_data)
+        elif command == "patch":
+            patch(__id, json_data)
     if command != "delete":
         user_data.set_meta(meta_key, __id)
 
@@ -75,17 +87,21 @@ def cli(command, name, rename, description, quality_status, junit_file):
 
 
 def delete(__id):
-    rep = tools.delete(__endpoint, __id, "test results")
+    rep = tools.delete(get_end_point(), __id, "test results")
     print(rep.text)
 
 
-def put(__id, description, quality_status, rename):
-    json_data = create_json(rename, description, quality_status)
+def put(__id, json_data):
     json_data = set_empty_fields_with_blank(json_data)
     rep = rest_crud.put(get_end_point(__id), json_data)
     tools.get_id_and_print_json(rep)
 
 
+def patch(__id, json_data):
+    rep = rest_crud.patch(get_end_point(__id), json_data)
+    tools.get_id_and_print_json(rep)
+
+
 def set_empty_fields_with_blank(json_data):
     if 'description' not in json_data:
         json_data['description'] = ''
@@ -98,7 +114,44 @@ def junit(__id, junit_file):
     json_result = rest_crud.get(get_end_point(__id))
     json_sla_test = rest_crud.get(get_end_point(__id, __operation_sla_test))
     json_sla_interval = rest_crud.get(get_end_point(__id, __operation_sla_interval))
-    displayer.print_result_junit(json_result, json_sla_test, json_sla_interval, junit_file)
+    json_sla_global = rest_crud.get(get_end_point(__id, __operation_sla_global))
+    displayer.print_result_junit(json_result, json_sla_test, json_sla_interval, json_sla_global, junit_file)
+
+
+def get_id_by_name_or_id(name):
+    if name == "cur":
+        name = user_data.get_meta(meta_key)
+    is_id = tools.is_id(name)
+
+    __id = tools.get_id(name, __resolver, is_id)
+
+    if not __id:
+        __id = user_data.get_meta_required(meta_key)
+
+    return __id
+
+def get_json_summary(__id):
+    return {
+        "summary": rest_crud.get(get_end_point(__id))
+    }
+
+def get_sla_data_by_name_or_id(name):
+    __id = get_id_by_name_or_id(name)
+
+    json_result = rest_crud.get(get_end_point(__id))
+    status = json_result['status']
+    json_sla_global = [] if status != 'TERMINATED' else rest_crud.get(get_end_point(__id, __operation_sla_global))
+    json_sla_test = [] if status != 'TERMINATED' else rest_crud.get(get_end_point(__id, __operation_sla_test))
+    json_sla_interval = rest_crud.get(get_end_point(__id, __operation_sla_interval))
+    json_stats = rest_crud.get(get_end_point(__id, __operation_statistics))
+    return {
+        'id': __id,
+        'result': json_result,
+        'stats': json_stats,
+        'sla_global': json_sla_global,
+        'sla_test': json_sla_test,
+        'sla_interval': json_sla_interval
+    }
 
 
 def summary(__id):
@@ -118,8 +171,9 @@ def get_id(name, is_id):
         return __resolver.resolve_name(name)
 
 
-def get_end_point(id_test: str, operation=''):
-    return __endpoint + "/" + id_test + operation
+def get_end_point(id_test: str = None, operation=''):
+    slash_id_test = '' if id_test is None else '/' + id_test
+    return rest_crud.base_endpoint_with_workspace() + __endpoint + slash_id_test + operation
 
 
 def create_json(name, description, quality_status):
@@ -130,18 +184,9 @@ def create_json(name, description, quality_status):
         data['description'] = description
     if quality_status is not None:
         data['qualityStatus'] = quality_status
-
-    if len(data) == 0:
-        if sys.stdin.isatty():
-            for field in ['name', 'description', 'qualityStatus']:
-                data[field] = input(field)
-        else:
-            try:
-                return json.loads(sys.stdin.read())
-            except json.JSONDecodeError as err:
-                raise cli_exception.CliException('%s\nThis command requires a valid Json input.\n'
-                                                 'Example: neoload test-results put {"name":"TestResultName"}' % str(
-                    err))
+    if len(data) == 0 and sys.stdin.isatty():
+        for field in ['name', 'description', 'qualityStatus']:
+            data[field] = input(field)
     return data
 
 
@@ -163,6 +208,8 @@ def exit_process(json_data, json_sla_global, json_sla_test, json_sla_interval):
         return {'message': "Test failed because of license.", 'code': 2}
     elif term_reason == "UNKNOWN":
         return {'message': "Test failed for an unknown reason. Check logs.", 'code': 2}
+    elif term_reason == "RESERVATION_ENDED":
+        return {'message': "Test was stopped because the reservation ended.", 'code': 2}
     elif sla_failure_count > 0:
         return {'message': f'Test completed with {sla_failure_count} SLAs failures.', 'code': 1}
     elif term_reason == "POLICY":
